========================
hiperwalk.IntegerLattice
========================

.. currentmodule:: hiperwalk

.. autofunction:: IntegerLattice

Methods
-------

Besides all methods inherited from
:class:`hiperwalk.Graph`,
:class:`hiperwalk.Multigraph`,
or :class:`hiperwalk.WeightedGraph`,
an integer lattice instance also has the following method.

.. currentmodule:: hiperwalk.graph.integer_lattice

.. autosummary::
   :toctree: generated

    dimensions
    vertex_coordinates
